@@ -13,15 +13,16 @@ namespace std {
 #if defined(toupper)
 #undef toupper
 extern int toupper(int c);
-#else
-#define HAVE_TOUPPER 1
 #endif
 
 #if defined(tolower)
 #undef tolower
 extern int tolower(int c);
-#else
-#define HAVE_TOLOWER 1
+#endif
+
+#if defined(isalpha)
+#undef isalpha
+extern int isalpha(int c);
 #endif
 
 #if ! HAVE_BIND_TEXTDOMAIN_CODESET
@@ -54,22 +55,10 @@ extern int snprintf(char *str, size_t size, const char *format, ...);
 extern double sqrt(double x);
 #endif
 
-#if ! HAVE_STRCASECMP
-extern int strcasecmp(const char *s1, const char *s2);
-#endif
-
 #if ! HAVE_STRLEN
 extern size_t strlen(const char *s);
 #endif
 
-#if ! HAVE_STRNCASECMP
-extern int strncasecmp(const char *s1, const char *s2, size_t n);
-#endif
-
-#if ! HAVE_STRSTR
-extern char *strstr(const char *haystack, const char *needle);
-#endif
-
 #if ! HAVE_STRTOD
 extern double strtod(const char *nptr, char **endptr);
 #endif
