@@ -270,7 +270,7 @@ void my_gtk_list_setup (GtkWidget *box, GtkTreeView **treeviewptr,
 #define COL_SETUP(Text, Index) do { \
   renderer = gtk_cell_renderer_text_new (); \
   column = gtk_tree_view_column_new_with_attributes (Text, renderer, \
-      "text", Index, 0); \
+      "text", Index, NULL); \
   gtk_tree_view_column_set_sort_column_id (column, Index); \
   gtk_tree_view_append_column (treeview, column); } while (0)
   
@@ -336,7 +336,7 @@ void update_info(GtkTreeView *treeview)
   else if (namecol && strcmp(_("Label"), col_label)) {
     GtkCellRenderer *renderer = gtk_cell_renderer_text_new ();
     column = gtk_tree_view_column_new_with_attributes (_("Label"), renderer,
-        "text", COL_INDEX, 0);
+        "text", COL_INDEX, NULL);
     gtk_tree_view_column_set_sort_column_id (column, COL_INDEX);
     gtk_tree_view_insert_column (treeview, column, 0);
   }
