@@ -97,7 +97,7 @@ static gint expose_event( GtkWidget      *widget,
 }
 
 
-void redraw_all(changetype_t changetype)
+void redraw_all(star_changetype_t changetype)
 {
   globals::chart_stararray->SetRules(globals::chart_rules, changetype);
   redraw_display(globals::program_canvas);
